@@ -1,6 +1,7 @@
-module Text.Atom.Tests where
+module Text.Atom.Tests
+  ( atomTests
+  ) where
 
-import Prelude ()
 import Prelude.Compat
 
 import Data.Maybe (isJust)
@@ -9,9 +10,9 @@ import Test.Framework.Providers.HUnit (testCase)
 import Test.HUnit (Assertion, assertBool)
 import Text.XML
 
-import Text.Atom.Feed
-import Text.Feed.Export
-import Text.Feed.Import
+import Text.Atom.Feed (TextContent(TextString), entryLinks, nullEntry, nullLink)
+import Text.Feed.Export (xmlFeed)
+import Text.Feed.Import (parseFeedFromFile)
 import Text.Feed.Query
 import Text.Feed.Types
 import Text.RSS.Utils
@@ -29,9 +30,9 @@ testFullAtomParse = testCase "parse a complete atom file" testAtom
   where
     testAtom :: Assertion
     testAtom = do
-      print . fmap (renderText def) . elementToDoc . xmlFeed =<<
-        parseFeedFromFile =<< getDataFileName "tests/files/atom.xml"
-      assertBool "OK" True
+      contents <- parseFeedFromFile =<< getDataFileName "tests/files/atom.xml"
+      let res = fmap (renderText def) . elementToDoc . xmlFeed $ contents
+      assertBool "Atom Parsing" $ isJust res
 
 testAtomAlternate :: Test
 testAtomAlternate = testCase "*unspecified* link relation means 'alternate'" testAlt
@@ -40,4 +41,4 @@ testAtomAlternate = testCase "*unspecified* link relation means 'alternate'" tes
     testAlt =
       let nullent = nullEntry "" (TextString "") ""
           item = AtomItem nullent {entryLinks = [nullLink ""]}
-      in assertBool "unspecified means alternate" $ isJust $ getItemLink item
+       in assertBool "unspecified means alternate" $ isJust $ getItemLink item
